{% for section, entries in sidebar %}
    <p class="menu-label">{{ section }}</p>
    <ul class="menu-list">
        {% for url, label, active in entries %}
            <li>
                <a href="{{ url }}" class="{% if active %}is-active{% endif %}">
                    {{ label }}
                </a>
            </li>
        {% endfor %}
    </ul>
{% endfor %}