"""Django app made to create backoffices to help the administration of a site, like
the Django Admin site, but for final users.
"""
__version__ = "2.1.1"


default_app_config = "backoffice_extensions.apps.BackofficeAppConfig"
